@@ -4,12 +4,13 @@ package Test::Class::Moose::AttributeRegistry;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 use Carp;
 use Class::MOP;
-use List::MoreUtils qw( any uniq );
+use List::SomeUtils qw( any uniq );
 
 my %BY_METHOD = (
     tags  => {},    # {$method}{$test_class}
@@ -190,13 +191,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::AttributeRegistry - Global registry of tags by class and method.
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =head1 SYNOPSIS
 
@@ -269,6 +272,12 @@ keyboard to Mark Morgan for his work on this).
 
 =back
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -283,9 +292,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
