@@ -4,21 +4,21 @@ package Test::Class::Moose::Executor::Parallel;
 
 use 5.10.0;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 use Moose 2.0000;
 use Carp;
 use namespace::autoclean;
 with 'Test::Class::Moose::Role::Executor';
 
-use List::MoreUtils qw(none);
+use List::SomeUtils qw(none);
 use Parallel::ForkManager;
 use TAP::Stream 0.44;
 use Test::Builder;
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Report::Class;
 
-use List::MoreUtils qw(uniq);
+use List::SomeUtils qw(uniq);
 
 has 'jobs' => (
     is       => 'ro',
@@ -207,16 +207,24 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Executor::Parallel - Execute tests in parallel (parallelized by instance)
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =for Pod::Coverage Tags Tests runtests
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -231,9 +239,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
