@@ -4,8 +4,9 @@ package Test::Class::Moose::Load;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 use File::Find;
 use File::Spec;
@@ -80,13 +81,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Load - Load L<Test::Class::Moose> classes automatically.
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =head1 SYNOPSIS
 
@@ -263,6 +266,11 @@ them. Please file a bug report if this is too restrictive.
 
  my ($package) = $_package =~ /^([[:word:]]+(?:::[[:word:]]+)*)$/;
 
+=head1 ACKNOWLEDGMENTS
+
+Thanks to David Wheeler for the idea and Adrian Howard for
+L<Test::Class::Moose>.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -271,10 +279,9 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Load>. I will be
 notified, and then you'll automatically be notified of progress on your bug as
 I make changes.
 
-=head1 ACKNOWLEDGMENTS
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
 
-Thanks to David Wheeler for the idea and Adrian Howard for
-L<Test::Class::Moose>.
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -290,9 +297,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
