@@ -2,9 +2,13 @@ package Test::Class::Moose::Role::AutoUse;
 
 # ABSTRACT: Automatically load the classes you're testing
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.10.0;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 use Moose::Role;
 use Carp 'confess';
@@ -38,13 +42,15 @@ sub get_class_name_to_use {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Role::AutoUse - Automatically load the classes you're testing
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =head1 SYNOPSIS
 
@@ -164,14 +170,6 @@ Yes, that's correct. We should have done this, except that now it's almost
 identical to the AutoUse code, except that the first time you forget to C<use>
 the class in question, you'll be unhappy. Why not automate this?
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as
-I make changes.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -200,6 +198,18 @@ L<http://search.cpan.org/dist/Test-Class-Moose/>
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
+notified, and then you'll automatically be notified of progress on your bug as
+I make changes.
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -214,9 +224,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
