@@ -4,14 +4,14 @@ package Test::Class::Moose::Role::Executor;
 
 use 5.10.0;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 use Moose::Role 2.0000;
 use Carp;
 use namespace::autoclean;
 
 use List::Util qw(shuffle);
-use List::MoreUtils qw(uniq);
+use List::SomeUtils qw(uniq);
 use Test::Builder;
 use Test::Most;
 use Try::Tiny;
@@ -340,16 +340,24 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =for Pod::Coverage test_classes
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -364,9 +372,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
